pub struct Cli {
pub dirty: bool,
pub ignored: bool,
pub ignore_older: bool,
pub quiet: bool,
pub paths: Option<Vec<String>>,
}Expand description
CLI utility that resets the timestamps of files in a Git repository working directory to the exact timestamp of the last commit which modified each file.
Fields
dirty: boolInclude files tracked by Git but modifications in the working tee
ignored: boolInclude files tracked by Git but also ignored
ignore_older: boolOnly touch files that are newer than their history, ignore ones that are older
quiet: boolDon’t print any output about files touched or skipped
paths: Option<Vec<String>>Optional list of paths to operate on instead of default which is all files tracked by Git